@@ -1,18 +1,17 @@
 """``runway gen-sample sls-tsc`` command."""
 import logging
-import sys
+from pathlib import Path
+from typing import TYPE_CHECKING, Any, cast
 
 import click
 
 from ... import options
 from .utils import TEMPLATES, convert_gitignore, copy_sample
 
-if sys.version_info.major > 2:
-    from pathlib import Path  # pylint: disable=E
-else:
-    from pathlib2 import Path  # pylint: disable=E
+if TYPE_CHECKING:
+    from ...._logging import RunwayLogger
 
-LOGGER = logging.getLogger(__name__.replace("._", "."))
+LOGGER = cast("RunwayLogger", logging.getLogger(__name__.replace("._", ".")))
 
 
 @click.command("sls-tsc", short_help="sls + tsc (sampleapp.sls)")
@@ -20,7 +19,7 @@ LOGGER = logging.getLogger(__name__.replace("._", "."))
 @options.no_color
 @options.verbose
 @click.pass_context
-def sls_tsc(ctx, **_):
+def sls_tsc(ctx: click.Context, **_: Any) -> None:
     """Generate a sample Serverless project using TypeScript."""
     src = TEMPLATES / "sls-tsc"
     dest = Path.cwd() / "sampleapp.sls"
