@@ -22,6 +22,7 @@ from ._module import Module
 if TYPE_CHECKING:
     from ...config.components.runway import RunwayDeploymentDefinition
     from ...context import RunwayContext
+    from ..type_defs import RunwayActionTypeDef
 
 
 LOGGER = logging.getLogger(__name__.replace("._", "."))
@@ -122,12 +123,25 @@ class Deployment:
 
         """
         self.logger.verbose(
-            "attempting to destroy in regions(s): %s", ", ".join(self.regions)
+            "attempting to destroy in region(s): %s", ", ".join(self.regions)
         )
         if self.use_async:
             return self.__async("destroy")
         return self.__sync("destroy")
 
+    def init(self) -> None:
+        """Initialize/bootstrap deployment.
+
+        High level method for running a deployment.
+
+        """
+        self.logger.verbose(
+            "attempting to initialize region(s): %s", ", ".join(self.regions)
+        )
+        if self.use_async:
+            return self.__async("init")
+        return self.__sync("init")
+
     def plan(self) -> None:
         """Plan for the next deploy of the deployment.
 
@@ -144,7 +158,7 @@ class Deployment:
             )
         return self.__sync("plan")
 
-    def run(self, action: str, region: str) -> None:
+    def run(self, action: RunwayActionTypeDef, region: str) -> None:
         """Run a single deployment in a single region.
 
         Low level API access to run a deployment object.
@@ -222,7 +236,7 @@ class Deployment:
             )
             self.ctx.env.vars = merge_dicts(self.ctx.env.vars, self.env_vars_config)
 
-    def __async(self, action: str) -> None:
+    def __async(self, action: RunwayActionTypeDef) -> None:
         """Execute asynchronously.
 
         Args:
@@ -242,7 +256,7 @@ class Deployment:
         for job in futures:
             job.result()  # raise exceptions / exit as needed
 
-    def __sync(self, action: str) -> None:
+    def __sync(self, action: RunwayActionTypeDef) -> None:
         """Execute synchronously.
 
         Args:
@@ -257,7 +271,7 @@ class Deployment:
     @classmethod
     def run_list(
         cls,
-        action: str,
+        action: RunwayActionTypeDef,
         context: RunwayContext,
         deployments: List[RunwayDeploymentDefinition],
         future: RunwayFutureDefinitionModel,
