@@ -4,6 +4,8 @@ from __future__ import annotations
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, List, Optional, Union
 
+from .utils import DOC_SITE
+
 if TYPE_CHECKING:
     from types import ModuleType
 
@@ -174,6 +176,24 @@ class InvalidLookupConcatenation(RunwayError):
         super().__init__(*args, **kwargs)
 
 
+class KubectlVersionNotSpecified(RunwayError):
+    """kubectl version is required but was not specified.
+
+    Version can be specified by using a file or option.
+
+    """
+
+    message: str
+
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
+        """Instantiate class."""
+        self.message = (
+            "kubectl version not specified. Learn how to use Runway to manage kubectl versions "
+            f"at {DOC_SITE}/page/kubernetes/advanced_features.html#version-management"
+        )
+        super().__init__(*args, **kwargs)
+
+
 class NpmNotFound(RunwayError):
     """Raised when npm could not be executed or was not found in path."""
 
@@ -204,7 +224,7 @@ class OutputDoesNotExist(RunwayError):
         self.stack_name = stack_name
         self.output = output
 
-        self.message = "Output %s does not exist on stack %s" % (output, stack_name)
+        self.message = f"Output {output} does not exist on stack {stack_name}"
         super().__init__(*args, **kwargs)
 
 
