@@ -8,6 +8,7 @@ from typing import TYPE_CHECKING, Any, Dict, Optional, Sequence, Set, Tuple, Uni
 
 import yaml
 from troposphere import BaseAWSObject
+from typing_extensions import Literal
 
 from ...cfngin.utils import read_value_from_path
 from ...utils import MutableMap
@@ -19,6 +20,8 @@ if TYPE_CHECKING:
 
 LOGGER = logging.getLogger(__name__)
 
+TransformToTypeLiteral = Literal["bool", "str"]
+
 
 class LookupHandler:
     """Base class for lookup handlers."""
@@ -38,7 +41,7 @@ class LookupHandler:
         value: Any,
         get: Optional[str] = None,
         load: Optional[str] = None,
-        transform: Optional[str] = None,
+        transform: Optional[TransformToTypeLiteral] = None,
         **kwargs: Any,
     ) -> Any:
         """Format results to be returned by a lookup.
@@ -60,7 +63,9 @@ class LookupHandler:
         1. :meth:`load` if ``load`` is provided.
         2. :meth:`runway.util.MutableMap.find` or :meth:`dict.get` depending
            on the data type if ``get`` is provided.
-        3. :meth:`transform` if ``transform`` is provided.
+        3. Convert null value string to ``NoneType`` object. This includes string
+           values of "None" and "null". This conversion is case insensitive.
+        4. :meth:`transform` if ``transform`` is provided.
 
         """
         if load:
@@ -72,10 +77,14 @@ class LookupHandler:
                 value = value.get(get)
             else:
                 raise TypeError(
-                    'value must be dict type to use "get"; got type "{}"'.format(
-                        type(value)
-                    )
+                    f'value must be dict type to use "get"; got type "{type(value)}"'
                 )
+        if (
+            isinstance(value, str)
+            and value.lower() in ["none", "null"]
+            and transform != "str"  # retain string "as is" if should be str
+        ):
+            value = None
         if transform:
             return cls.transform(value, to_type=transform, **kwargs)
         if isinstance(value, MutableMap):
@@ -226,7 +235,11 @@ class LookupHandler:
 
     @classmethod
     def transform(
-        cls, value: Any, *, to_type: Optional[str] = "str", **kwargs: Any
+        cls,
+        value: Any,
+        *,
+        to_type: Optional[TransformToTypeLiteral] = "str",
+        **kwargs: Any,
     ) -> Any:
         """Transform the result of a lookup into another datatype.
 
@@ -267,9 +280,7 @@ class LookupHandler:
         if isinstance(value, str):
             return bool(strtobool(value))
         raise TypeError(
-            "Value must be a string or bool to use transform=bool. Got type {}.".format(
-                type(value)
-            )
+            f"Value must be a string or bool to use transform=bool. Got type {type(value)}."
         )
 
     @classmethod
@@ -289,7 +300,7 @@ class LookupHandler:
 
         """
         if isinstance(value, (list, set, tuple)):
-            return "{}".format(delimiter).join(cast(Sequence[str], value))
+            return f"{delimiter}".join(cast(Sequence[str], value))
         if isinstance(value, MutableMap):
             # convert into a dict with protected attrs removed
             value = value.data
